@@ -80,13 +80,15 @@ class ObschartClient:
           }
         ''' + programTrackActionResponseFragment)
 
+        filter = filter.copy()
+        filter.update({
+            'createdAt': {
+                'after': time.replace(
+                    tzinfo=datetime.timezone.utc).isoformat()
+            }
+        })
         variables = {
-            'filter': dict(filter).update({
-                'createdAt': {
-                    'after': time.replace(
-                        tzinfo=datetime.timezone.utc).isoformat()
-                }
-            })
+            'filter': filter
         }
 
         def poll():
@@ -112,7 +114,7 @@ class ObschartClient:
 
     def on_response(self, on_response_callback: OnResponseCallback):
         responses = self.poll_program_track_action_responses({
-            'applicationId': 'me'
+            'applicationId': {'eq': 'me'}
         })
 
         for response in responses:
